@@ -15,7 +15,12 @@ import aws_cdk.aws_sqs._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sns-subscriptions", "1.48.0", __name__[0:-6], "aws-sns-subscriptions@1.48.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-sns-subscriptions",
+    "1.51.0",
+    __name__[0:-6],
+    "aws-sns-subscriptions@1.51.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
